- fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy.patch removed from -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled

     fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy

has been removed from the -mm tree.  Its filename is

     fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy.patch

This patch was dropped because it was folded into fix-the-race-between-invalidate_inode_pages-and-do_no_page.patch

------------------------------------------------------
Subject: fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
From: Andrew Morton <akpm@xxxxxxxx>

Vowels have rights too, you know.

Cc: Nick Piggin <npiggin@xxxxxxx>
Cc: Andrea Arcangeli <andrea@xxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxx>
---

 fs/ncpfs/mmap.c             |    2 +-
 fs/ocfs2/mmap.c             |    2 +-
 fs/xfs/linux-2.6/xfs_file.c |    4 ++--
 include/linux/mm.h          |    2 +-
 mm/filemap.c                |    4 ++--
 mm/memory.c                 |    6 +++---
 mm/shmem.c                  |    4 ++--
 7 files changed, 12 insertions(+), 12 deletions(-)

diff -puN fs/ncpfs/mmap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy fs/ncpfs/mmap.c
--- a/fs/ncpfs/mmap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/fs/ncpfs/mmap.c
@@ -100,7 +100,7 @@ static struct page* ncp_file_mmap_nopage
 static struct vm_operations_struct ncp_file_mmap =
 {
 	.nopage	= ncp_file_mmap_nopage,
-	.vm_flags = VM_CAN_INVLD,
+	.vm_flags = VM_CAN_INVALIDATE,
 };
 
 
diff -puN fs/ocfs2/mmap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy fs/ocfs2/mmap.c
--- a/fs/ocfs2/mmap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/fs/ocfs2/mmap.c
@@ -78,7 +78,7 @@ out:
 
 static struct vm_operations_struct ocfs2_file_vm_ops = {
 	.nopage = ocfs2_nopage,
-	.vm_flags = VM_CAN_INVLD,
+	.vm_flags = VM_CAN_INVALIDATE,
 };
 
 int ocfs2_mmap(struct file *file, struct vm_area_struct *vma)
diff -puN fs/xfs/linux-2.6/xfs_file.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy fs/xfs/linux-2.6/xfs_file.c
--- a/fs/xfs/linux-2.6/xfs_file.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/fs/xfs/linux-2.6/xfs_file.c
@@ -597,7 +597,7 @@ const struct file_operations xfs_dir_fil
 static struct vm_operations_struct xfs_file_vm_ops = {
 	.nopage		= filemap_nopage,
 	.populate	= filemap_populate,
-	.vm_flags	= VM_CAN_INVLD,
+	.vm_flags	= VM_CAN_INVALIDATE,
 };
 
 #ifdef CONFIG_XFS_DMAPI
@@ -607,6 +607,6 @@ static struct vm_operations_struct xfs_d
 #ifdef HAVE_VMOP_MPROTECT
 	.mprotect	= xfs_vm_mprotect,
 #endif
-	.vm_flags	= VM_CAN_INVLD,
+	.vm_flags	= VM_CAN_INVALIDATE,
 };
 #endif /* CONFIG_XFS_DMAPI */
diff -puN include/linux/mm.h~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy include/linux/mm.h
--- a/include/linux/mm.h~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/include/linux/mm.h
@@ -165,7 +165,7 @@ extern unsigned int kobjsize(const void 
 #define VM_NONLINEAR	0x00800000	/* Is non-linear (remap_file_pages) */
 #define VM_MAPPED_COPY	0x01000000	/* T if mapped copy of data (nommu mmap) */
 #define VM_INSERTPAGE	0x02000000	/* The vma has had "vm_insert_page()" done on it */
-#define VM_CAN_INVLD	0x04000000	/* The mapping may be invalidated,
+#define VM_CAN_INVALIDATE 0x04000000	/* The mapping may be invalidated,
 					 * eg. truncate or invalidate_inode_*.
 					 * In this case, do_no_page must
 					 * return with the page locked.
diff -puN mm/filemap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy mm/filemap.c
--- a/mm/filemap.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/mm/filemap.c
@@ -1384,7 +1384,7 @@ struct page *filemap_nopage(struct vm_ar
 	unsigned long size, pgoff;
 	int did_readaround = 0, majmin = VM_FAULT_MINOR;
 
-	BUG_ON(!(area->vm_flags & VM_CAN_INVLD));
+	BUG_ON(!(area->vm_flags & VM_CAN_INVALIDATE));
 
 	pgoff = ((address-area->vm_start) >> PAGE_CACHE_SHIFT) + area->vm_pgoff;
 
@@ -1710,7 +1710,7 @@ EXPORT_SYMBOL(filemap_populate);
 struct vm_operations_struct generic_file_vm_ops = {
 	.nopage		= filemap_nopage,
 	.populate	= filemap_populate,
-	.vm_flags	= VM_CAN_INVLD,
+	.vm_flags	= VM_CAN_INVALIDATE,
 };
 
 /* This is used for a general mmap of a disk file */
diff -puN mm/shmem.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy mm/shmem.c
--- a/mm/shmem.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/mm/shmem.c
@@ -1225,7 +1225,7 @@ struct page *shmem_nopage(struct vm_area
 	unsigned long idx;
 	int error;
 
-	BUG_ON(!(vma->vm_flags & VM_CAN_INVLD));
+	BUG_ON(!(vma->vm_flags & VM_CAN_INVALIDATE));
 
 	idx = (address - vma->vm_start) >> PAGE_SHIFT;
 	idx += vma->vm_pgoff;
@@ -2226,7 +2226,7 @@ static struct vm_operations_struct shmem
 	.set_policy     = shmem_set_policy,
 	.get_policy     = shmem_get_policy,
 #endif
-	.vm_flags	= VM_CAN_INVLD,
+	.vm_flags	= VM_CAN_INVALIDATE,
 };
 
 
_

Patches currently in -mm which might be from akpm@xxxxxxxx are

origin.patch
disable-debugging-version-of-write_lock.patch
fadvise-make-posix_fadv_noreuse-a-no-op.patch
acpi-asus-s3-resume-fix.patch
sony_apci-resume.patch
kauditd_thread-warning-fix.patch
git-block-mmc-fix.patch
git-block-dm-emc-fix.patch
fix-gregkh-driver-driver-multithread.patch
revert-gregkh-driver-class_device_rename-remove.patch
revert-gregkh-driver-network-class_device-to-device.patch
revert-gregkh-driver-tty-device.patch
revert-gregkh-driver-mem-devices.patch
add-__must_check-to-device-management-code.patch
add-config_enable_must_check.patch
v4l-dev2-handle-__must_check.patch
drivers-base-check-errors.patch
drivers-base-check-errors-fix.patch
sysfs-add-proper-sysfs_init-prototype.patch
scsi-device_reprobe-can-fail.patch
git-dvb.patch
git-dvb-fixup.patch
git-gfs2.patch
git-ia64.patch
git-ieee1394-fixup.patch
git-input.patch
logips2pp-fix-mx300-button-layout.patch
git-libata-all.patch
sata-is-bust-on-s390.patch
rework-legacy-handling-to-remove-much-of-the-cruft-fix.patch
rework-legacy-handling-to-remove-much-of-the-cruft-powerpc-fix.patch
asus-mv-device-ids.patch
git-netdev-all.patch
82596-section-fixes.patch
ac3200-section-fixes.patch
cops-section-fix.patch
cs89x0-section-fix.patch
at1700-section-fix.patch
e2100-section-fix.patch
eepro-section-fix.patch
eexpress-section-fix.patch
es3210-section-fix.patch
eth16i-section-fix.patch
lance-section-fix.patch
lne390-section-fix.patch
ni52-section-fix.patch
ibmtr-section-fix.patch
smctr-section-fix.patch
wd-section-fix.patch
ni65-section-fix.patch
seeq8005-section-fix.patch
winbond-840-section-fix.patch
fealnx-section-fix.patch
sundance-section-fix.patch
e1000_7033_dump_ring-fix.patch
s2io-build-fix.patch
drivers-net-ns83820c-add-paramter-to-disable-auto.patch
ppp-handle-kmalloc-failures-leak-fix.patch
ppp-handle-kmalloc-failures-leak-tweaks.patch
xt_physdev-build-fix.patch
fix-memory-leak-in-net-ipv4-tcp_probectcpprobe_read.patch
git-nfs.patch
git-pcmcia-fixup.patch
git-powerpc.patch
git-sas.patch
git-block-vs-git-sas.patch
serial-fix-uart_bug_txen-test.patch
pcie-check-and-return-bus_register-errors-fix.patch
git-kbuild-build-fix.patch
git-scsi-misc.patch
fix-panic-when-reinserting-adaptec-pcmcia-scsi-card-tidy.patch
areca-sysfs-fix.patch
git-scsi-target-fixup.patch
git-scsi-target-vs-git-block.patch
usb-hub-driver-improve-use-of-ifdef-fix.patch
pm-usb-hcds-use-pm_event_prethaw-fix.patch
kill-usb-kconfig-warning.patch
rtl8150_disconnect-needs-tasklet_kill.patch
git-supertrak-fixup.patch
git-watchdog.patch
git-wireless-bcm43xx-fix.patch
kthread-airoc-race-fix.patch
fix-x86_64-mm-via-force-dma-mask-config_pcin-fix.patch
fix-x86_64-mm-allow-users-to-force-a-panic-on-nmi.patch
sleazy-fpu-feature-x86_64-support.patch
x86_64-wire-up-oops_enter-oops_exit.patch
git-geode-vs-git-cryptodev.patch
adix-tree-rcu-lockless-readside-update-tidy.patch
mm-tracking-shared-dirty-pages-checks.patch
mm-tracking-shared-dirty-pages-wimp.patch
convert-i386-numa-kva-space-to-bootmem-tidy.patch
reduce-max_nr_zones-make-display-of-highmem-counters-conditional-on-config_highmem-tidy.patch
reduce-max_nr_zones-use-enum-to-define-zones-reformat-and-comment-cleanup.patch
reduce-max_nr_zones-remove-display-of-counters-for-unconfigured-zones-s390-fix.patch
out-of-memory-notifier-tidy.patch
mm-swap-write-failure-fixup-fix.patch
fix-the-race-between-invalidate_inode_pages-and-do_no_page.patch
fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy.patch
acx1xx-wireless-driver.patch
tiacx-pci-build-fix.patch
tiacx-ia64-fix.patch
tiacx-build-fix.patch
binfmt_elf-consistently-use-loff_t.patch
add-force-of-use-mmconfig-fix.patch
convert-i386-summit-subarch-to-use-srat-info-for-apicid_to_node-calls-tidy.patch
add-efi-e820-memory-mapping-on-x86.patch
add-efi-e820-memory-mapping-on-x86-tidy.patch
add-efi-e820-memory-mapping-on-x86-fix.patch
x86-increase-max_mp_busses-on-default-arch.patch
i386-adds-smp_call_function_single-fix.patch
swsusp-write-timer.patch
swsusp-write-speedup.patch
swsusp-read-timer.patch
swsusp-read-speedup.patch
swsusp-read-speedup-fix.patch
swsusp-read-speedup-cleanup.patch
swsusp-read-speedup-cleanup-2.patch
deprecate-smbfs-in-favour-of-cifs.patch
edac-new-opteron-athlon64-memory-controller-driver-tidy.patch
inode_diet-replace-inodeugeneric_ip-with-inodei_private-gfs-fix.patch
x86-microcode-microcode-driver-cleanup-tidy.patch
x86-microcode-add-sysfs-and-hotplug-support-fix.patch
eisa-bus-modalias-attributes-support-1-fix-git-kbuild-fix.patch
add-address_space_operationsbatch_write-fix.patch
alloc_fdtable-cleanup.patch
add-probe_kernel_address.patch
x86-use-probe_kernel_address-in-handle_bug.patch
blockdevc-check-errors.patch
let-warn_on-warn_on_once-return-the-condition-fix.patch
let-warn_on-warn_on_once-return-the-condition-fix-2.patch
omap-add-watchdog-driver-support-tweaks.patch
move-valid_dma_direction-from-x86_64-to-generic-code-fix.patch
reiserfs-on-demand-bitmap-loading.patch
streamline-generic_file_-interfaces-and-filemap-gfs-fix.patch
stack-overflow-safe-kdump-crash_use_safe_smp_processor_id-fix.patch
knfsd-add-a-callback-for-when-last-rpc-thread-finishes-tidy.patch
knfsd-add-a-callback-for-when-last-rpc-thread-finishes-fix.patch
knfsd-separate-out-some-parts-of-nfsd_svc-which-start-nfs-servers-tweaks.patch
knfsd-define-new-nfsdfs-file-portlist-contains-list-of-ports-tidy.patch
knfsd-define-new-nfsdfs-file-portlist-contains-list-of-ports-fix.patch
knfsd-have-ext2-reject-file-handles-with-bad-inode-numbers-early-tidy.patch
knfsd-make-ext3-reject-filehandles-referring-to-invalid-inode-numbers-tidy.patch
knfsd-drop-serv-option-to-svc_recv-and-svc_process-nfs-callback-fix-nfs-callback-fix.patch
knfsd-move-tempsock-aging-to-a-timer-tidy.patch
swap_prefetch-vs-zoned-counters.patch
ecryptfs-mmap-operations.patch
ecryptfs-alpha-build-fix.patch
ecryptfs-more-elegant-aes-key-size-manipulation.patch
ecryptfs-get_sb_dev-fix.patch
namespaces-add-nsproxy-dont-include-compileh.patch
namespaces-utsname-switch-to-using-uts-namespaces.patch
namespaces-utsname-use-init_utsname-when-appropriate.patch
namespaces-utsname-implement-utsname-namespaces.patch
namespaces-utsname-sysctl-hack.patch
namespaces-utsname-switch-to-using-uts-namespaces-klibc-bit-sparc.patch
ipc-namespace-core.patch
readahead-sysctl-parameters-fix.patch
make-copy_from_user_inatomic-not-zero-the-tail-on-i386-vs-reiser4.patch
reiser4-hardirq-include-fix.patch
reiser4-run-truncate_inode_pages-in-reiser4_delete_inode.patch
reiser4-get_sb_dev-fix.patch
reiser4-vs-zoned-allocator.patch
hpt3xx-rework-rate-filtering-tidy.patch
asus-mv-ide-device-ids.patch
genirq-convert-the-i386-architecture-to-irq-chips.patch
genirq-x86_64-irq-reenable-migrating-irqs-to-other-cpus.patch
genirq-msi-simplify-msi-enable-and-disable.patch
genirq-ia64-irq-dynamic-irq-support.patch
genirq-msi-only-build-msi-apicc-on-ia64-fix.patch
genirq-i386-irq-remove-the-msi-assumption-that-irq-==-vector.patch
genirq-x86_64-irq-make-vector_irq-per-cpu-fix.patch
add-hypertransport-capability-defines-fix.patch
initial-generic-hypertransport-interrupt-support-Kconfig-fix.patch
srcu-report-out-of-memory-errors-fixlet.patch
nr_blockdev_pages-in_interrupt-warning.patch
device-suspend-debug.patch
revert-tty-buffering-comment-out-debug-code.patch
slab-leaks3-default-y.patch
x86-kmap_atomic-debugging.patch
restore-rogue-readahead-printk.patch
jmicron-warning-fix.patch

-
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux
diff -puN mm/memory.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy mm/memory.c
--- a/mm/memory.c~fix-the-race-between-invalidate_inode_pages-and-do_no_page-tidy
+++ a/mm/memory.c
@@ -1661,10 +1661,10 @@ static int unmap_mapping_range_vma(struc
 
 	/*
 	 * files that support invalidating or truncating portions of the
 	 * file from under mmaped areas must set the VM_CAN_INVLD flag, and
 	 * have their .nopage function return the page locked.
 	 */
-	BUG_ON(!(vma->vm_flags & VM_CAN_INVLD));
+	BUG_ON(!(vma->vm_flags & VM_CAN_INVALIDATE));
 
 again:
 	restart_addr = vma->vm_truncate_count;
@@ -2223,7 +2223,7 @@ unlock:
 		put_page(dirty_page);
 	}
 out:
-	if (likely(vma->vm_flags & VM_CAN_INVLD))
+	if (likely(vma->vm_flags & VM_CAN_INVALIDATE))
 		unlock_page(old_page);
 	return ret;
 oom:
@@ -1661,10 +1661,10 @@ static int unmap_mapping_range_vma(struc
 	/*
 	 * files that support invalidating or truncating portions of the
-	 * file from under mmaped areas must set the VM_CAN_INVLD flag, and
+	 * file from under mmaped areas must set the VM_CAN_INVALIDATE flag, and
 	 * have their .nopage function return the page locked.
 	 */